# MusclesInTime

The `musint` package provided in this repository is the companion python package for our Muscles in Time dataset. It allows for easy access to the data. Methods for getting public access to our datasets will be provided at a later stage.
